@@ -9,7 +9,7 @@ use Net::Amazon::Request::Blended;
 use Log::Log4perl qw(:easy);
 Log::Log4perl->easy_init($DEBUG);
 
-my $ua = Net::Amazon->new(token => 'AMAZON_TOKEN');
+my $ua = Net::Amazon->new(token => $ENV{AMAZON_TOKEN});
 my $response = $ua->search(blended => ($ARGV[0] || "Perl"));
 
 if($response->is_success()) {
